summaryrefslogtreecommitdiff
path: root/keyboards/inland/kb83/kb83.c
diff options
context:
space:
mode:
Diffstat (limited to 'keyboards/inland/kb83/kb83.c')
-rw-r--r--keyboards/inland/kb83/kb83.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/keyboards/inland/kb83/kb83.c b/keyboards/inland/kb83/kb83.c
index 86b52cfe92..49604b93be 100644
--- a/keyboards/inland/kb83/kb83.c
+++ b/keyboards/inland/kb83/kb83.c
@@ -18,8 +18,8 @@
// clang-format off
#ifdef RGB_MATRIX_ENABLE
-const is31_led PROGMEM g_is31_leds[RGB_MATRIX_LED_COUNT] = {
-/* Refer to IS31 manual for these locations
+const snled27351_led_t PROGMEM g_snled27351_leds[RGB_MATRIX_LED_COUNT] = {
+/* Refer to SNLED27351 manual for these locations
* driver
* | R location
* | | G location